# pyqtcolordialog

A drop-in replacement of `QColorDialog` for `PyQt5`.

![](docs/demo.webp)

<table>
    <tr>
        <th>Before:</th>
        <th>After:</th>
    </tr>
    <tr>
        <td><img src='docs/old2.png'/></td>
        <td><img src='docs/new2.png'/></td>
    </tr>
</table>

## Installation

`pip install pyqtcolordialog --user`
